@@ -3,7 +3,7 @@ package Task::Sympa;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 1;
 
@@ -15,10 +15,6 @@ __END__
 
 Task::Sympa - Sympa dependencies
 
-=head1 VERSION
-
-version 1.01
-
 =head1 SYNOPSIS
 
 This is just a Task module to install dependencies. There's no code to use
@@ -29,6 +25,7 @@ or run.
 Installing this module will install all the modules needed for running Sympa
 mailing-list manager, ie:
 
+
 =over
 
 =item * Archive::Zip
@@ -85,10 +82,20 @@ mailing-list manager, ie:
 
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over
+
+=item
 
 Guillaume Rousse <guillomovitch@cpan.org>
 
+=item
+
+Marc Chantreux <marc.chantreux@renater.fr>
+
+=back
+
 =head1 LICENSE
 
 This software is licensed under the terms of GPLv2+.
